==> gallery-0.5.8.module.tgz: modules/gallery/main.inc.php <==
<?php

	/*
	*	Gekko - Open Source Web Development Framework
	*	------------------------------------------------------------------------
	*	Copyright (C) 2004-2005, J. Carlos Nieto <xiam@users.sourceforge.net>
	*	This program is Free Software.
	*
	*	@package	Gekko
	*	@license	http://www.gnu.org/copyleft/gpl.html GNU/GPL License 2.0
	*	@author		J. Carlos Nieto <xiam@users.sf.net>
	*	@version	CVS: $Id:$
	*	@link		http://gekkoware.sourceforge.net
	*/

	if (!defined("IN-GEKKO")) die("Get a life!");

	require_once GEKKO_ROOT."modules/comments/main.lib.php";
	require_once GEKKO_ROOT."modules/gallery/main.lib.php";
	require_once GEKKO_ROOT."lib/format.lib.php";

	$action		= _ext("action", 1);
	$page		= _ext("page", 1);
	$id			= _ext("id", 2);

	switch ($action) {
		case "view":
			// getting id
			$id = intval($id);
			if ($id < 1 || _ext("id"))
				$id = _ext("id");

			// getting page
			$page = _ext("page", 3);

			if ($id) {

				$tpl = new contentBlock();
				$tpl->insert("BLOCK_CONTENT", "gallery/view_item.tpl");

				$db->query("SELECT ID, Title, Description, MediaURL, MediaSize, Thumbnail,
				ThumbnailSize, AuthorID, LastUpdated, AllowComments
				FROM ".db_table("gallery_item")." WHERE ID = '$id'", __FILE__, __LINE__);

				$row = $db->fetch_row();

				/* media size */
				$mediasize = explode("x", $row["MediaSize"]);
				if (count($mediasize) == 2) {
					$larger = conf::getKey("gallery", "item.larger_size", 342, "i");

					$mediasize[intval($mediasize[0]>$larger)] = $mediasize[($mediasize[0]>$larger)]*$larger/$mediasize[intval(!($mediasize[0]>$larger))];
					$mediasize[intval(!($mediasize[0]>$larger))] = $larger;

					list($row["MEDIA.WIDTH"], $row["MEDIA.HEIGHT"]) = $mediasize;
				}

				// thumbnail
				list($row["THUMBNAIL.WIDTH"], $row["THUMBNAIL.HEIGHT"]) = explode("x", $row["ThumbnailSize"]);

				$row["MediaURL"] = rel_link($row["MediaURL"]);
				/* guessing media type */
				switch (get_media_type($row["MediaURL"])) {
					case "image":
						// simple image
						$row["OBJECT"] = "<a href=\"{$row["MediaURL"]}\"><img class=\"photo\" src=\"{$row["MediaURL"]}\" width=\"{$row["MEDIA.WIDTH"]}\" height=\"{$row["MEDIA.HEIGHT"]}\" alt=\"{$row["Title"]}\" title=\"{$row["Title"]} - {$row["MediaSize"]}\" /></a>";
					break;
					case "flash":
						// macromedia flash object
						$row["OBJECT"] = "<object classid=\"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000\" codebase=\"http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=6,0,29,0\" width=\"{$row["MEDIA.WIDTH"]}\" height=\"{$row["MEDIA.HEIGHT"]}\"><param name=\"movie\" value=\"{$row["MediaURL"]}\"><param name=\"quality\" value=\"high\"><embed src=\"{$row["MediaURL"]}\" quality=\"high\" pluginspage=\"http://www.macromedia.com/go/getflashplayer\" type=\"application/x-shockwave-flash\" width=\"{$row["MEDIA.WIDTH"]}\" height=\"{$row["MEDIA.HEIGHT"]}\"></embed></object><br /><a href=\"{$row["MediaURL"]}\">("._l("L_CLICK_TO_DOWNLOAD").")</a>";
					break;
					default:
						// unknown
						$row["OBJECT"] = "<a href=\"{$row["MediaURL"]}\"><img class=\"photo\" src=\""._l("C_SITE.REL_URL")."{$row["Thumbnail"]}\" width=\"{$row["THUMBNAIL.WIDTH"]}\" height=\"{$row["THUMBNAIL.HEIGHT"]}\" alt=\"{$row["Title"]}\" title=\"{$row["Title"]}\" /></a><br />("._l("L_CLICK_TO_DOWNLOAD").")";
					break;
				}

				$row["AUTHOR"] = getUserById($row["AuthorID"]);

				$row["BLOCK_TITLE"] = $row["Title"];
				$row["BLOCK_ICON"] = mkIcon("gallery.png", 16);

				$tpl->set_arr($row);

				$mcBuff = $tpl->make();

				// loading comments
				if ($row["AllowComments"]) {
					$mcBuff .= LoadCommentsBlock (
						"gallery",
						$row["ID"],
						"index.php/gallery/item/".urlencode($row["Title"])."?id={$row["ID"]}&page=%p",
						$page,
						$row["Title"]
					);
				}
			} else {
				$mcBuff = accessDenied();
			}
		break;
		case "items":

			$id = _ext("id");
			$page = _ext("page");

			$tpl = new contentBlock();

			$tpl->insert("BLOCK_CONTENT", "gallery/view_gallery.tpl");

			$db->query("SELECT
			ID, Title, Description, Thumbnail, ThumbnailSize, auth_Access
			FROM ".db_table("gallery")." WHERE ID = '{$id}'",
			__FILE__, __LINE__);

			$row = $db->fetch_row();

			if ($db->num_rows() && gauth($row["auth_Access"])) {

				/* subgalleries */
				$allowed_galleries_sql = "(ID = '".implode("' OR ID ='", get_allowed_categories($row["ID"]))."')";

				$db->query ("SELECT
				ID, Title, Description, Thumbnail, ThumbnailSize, AuthorID, LastUpdated
				FROM ".db_table("gallery")." WHERE {$allowed_galleries_sql}",
				__FILE__, __LINE__);

				$subgalleries = $db->num_rows();
				while ($row2 = $db->fetch_row()) {
					gallery_row($row2);

					$tpl->set_arr($row2, "SUBGALLERY");
					$tpl->savebuff("SUBGALLERY");
				}

				/* gallery items */
				$pager = $db->pager (
					"SELECT ID FROM ".db_table("gallery_item")."
					WHERE GalleryLink = '{$row["ID"]}'",
					"index.php/gallery/items/".urlencode($row["Title"])."?id={$row["ID"]}&page=%p", $page, conf::getkey("gallery", "items_per_page")
				);

				$db->query("SELECT ID, Title, Description, Thumbnail, ThumbnailSize,
				LastUpdated, AuthorID, AllowComments
				FROM ".db_Table("gallery_item")."
				WHERE GalleryLink = '{$row["ID"]}' {$pager["sql"]}", __FILE__, __LINE__);

				$items = $db->num_rows();

				while ($row2 = $db->fetch_row()) {
					saneHTML($row2, "Description");
					gallery_row($row2, true);
					$row2["COMMENTSLINK"] = $row2["AllowComments"] ? mkCommentsLink("gallery", $row2["ID"], "index.php/gallery/items/{$row2["TITLE_ID"]}?id={$row2["ID"]}") : "";
					$tpl->set_arr($row2, "ITEM");
					$tpl->savebuff("ITEM");
				}

				$tpl->set_arr ($row);
				$tpl->set_arr (
					Array (
						"BLOCK_TITLE" => _l("L_GALLERY"),
						"BLOCK_ICON" => mkIcon("gallery.png", 16),
						"BLOCK_SUBTITLE" => $row["Title"],
						"ITEMS" => $items,
						"SUBGALLERIES" => $subgalleries,
						"PAGER" => $pager["html"]
					)
				);

				$mcBuff = $tpl->make();
			} else {
				$mcBuff = accessDenied();
			}
		break;
		default: {

			$tpl = new ContentBlock();
			$tpl->insert("BLOCK_CONTENT", "gallery/index.tpl");

			$allowed_galleries_sql = "(ID = '".implode("' OR ID ='", get_allowed_categories())."')";

			$pager = $db->pager (
				"SELECT ID FROM ".db_table("gallery")."
				WHERE {$allowed_galleries_sql} ORDER BY Title DESC",
				"index.php/gallery/%p", $page, conf::getKey("gallery", "items_per_page")
			);

			$db->query("SELECT
			ID, Title, Description, Thumbnail, ThumbnailSize, AuthorID, LastUpdated
			FROM ".db_table("gallery")." WHERE {$allowed_galleries_sql} ORDER BY
			Title DESC {$pager["sql"]}", __FILE__, __LINE__);

			$galleries = $db->num_rows();
			while ($row = $db->fetch_row()) {
				gallery_row($row);
				$tpl->set_arr($row, "GALLERY");
				$tpl->savebuff("GALLERY");
			}

			$tpl->set_arr (
				Array (
					"BLOCK_TITLE" => _l("L_GALLERY"),
					"BLOCK_SUBTITLE" => _l("L_GALLERIES"),
					"BLOCK_ICON" => mkIcon("gallery.png", 16),
					"PAGER" => $pager["html"],
					"GALLERIES" => $galleries
				)
			);

			$mcBuff = $tpl->make();

		}
	}

	// saving buffer
	$mc->save($mcBuff);

?>

==> gallery-0.5.10.module.tgz: modules/gallery/main.inc.php <==
<?php

	/*
	*	Gekko - Open Source Web Development Framework
	*	------------------------------------------------------------------------
	*	Copyright (C) 2004-2005, J. Carlos Nieto <xiam@users.sourceforge.net>
	*	This program is Free Software.
	*
	*	@package	Gekko
	*	@license	http://www.gnu.org/copyleft/gpl.html GNU/GPL License 2.0
	*	@author		J. Carlos Nieto <xiam@users.sf.net>
	*	@version	CVS: $Id:$
	*	@link		http://gekkoware.sourceforge.net
	*/

	if (!defined("IN-GEKKO")) die("Get a life!");

	require_once GEKKO_ROOT."modules/comments/main.lib.php";
	require_once GEKKO_ROOT."modules/gallery/main.lib.php";
	require_once GEKKO_ROOT."lib/format.lib.php";

	$action		= _ext("action", 1);
	$page		= _ext("page", 1);
	$id			= _ext("id", 2);

	switch ($action) {
		case "view":
			// getting id
			$id = intval($id);
			if ($id < 1 || _ext("id"))
				$id = _ext("id");

			// getting page
			$page = _ext("page", 3);

			if ($id) {

				$tpl = new contentBlock();
				$tpl->insert("BLOCK_CONTENT", "gallery/view_item.tpl");

				$db->query("SELECT ID, Title, Description, MediaURL, MediaSize, Thumbnail,
				ThumbnailSize, AuthorID, LastUpdated, AllowComments
				FROM ".db_table("gallery_item")." WHERE ID = '$id'", __FILE__, __LINE__);

				$row = $db->fetch_row();

				/* media size */
				$mediasize = explode("x", $row["MediaSize"]);
				if (count($mediasize) == 2) {
					$larger = conf::getKey("gallery", "item.larger_size", 342, "i");

					$mediasize[intval($mediasize[0]>$larger)] = $mediasize[($mediasize[0]>$larger)]*$larger/$mediasize[intval(!($mediasize[0]>$larger))];
					$mediasize[intval(!($mediasize[0]>$larger))] = $larger;

					list($row["MEDIA.WIDTH"], $row["MEDIA.HEIGHT"]) = $mediasize;
				}

				// thumbnail
				list($row["THUMBNAIL.WIDTH"], $row["THUMBNAIL.HEIGHT"]) = explode("x", $row["ThumbnailSize"]);

				$row["MediaURL"] = rel_link($row["MediaURL"]);
				/* guessing media type */
				switch (get_media_type($row["MediaURL"])) {
					case "image":
						// simple image
						$row["OBJECT"] = "<a href=\"{$row["MediaURL"]}\"><img class=\"photo\" src=\"{$row["MediaURL"]}\" width=\"{$row["MEDIA.WIDTH"]}\" height=\"{$row["MEDIA.HEIGHT"]}\" alt=\"{$row["Title"]}\" title=\"{$row["Title"]} - {$row["MediaSize"]}\" /></a>";
					break;
					case "flash":
						// macromedia flash object
						$row["OBJECT"] = "<object classid=\"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000\" codebase=\"http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=6,0,29,0\" width=\"{$row["MEDIA.WIDTH"]}\" height=\"{$row["MEDIA.HEIGHT"]}\"><param name=\"movie\" value=\"{$row["MediaURL"]}\"><param name=\"quality\" value=\"high\"><embed src=\"{$row["MediaURL"]}\" quality=\"high\" pluginspage=\"http://www.macromedia.com/go/getflashplayer\" type=\"application/x-shockwave-flash\" width=\"{$row["MEDIA.WIDTH"]}\" height=\"{$row["MEDIA.HEIGHT"]}\"></embed></object><br /><a href=\"{$row["MediaURL"]}\">("._l("L_CLICK_TO_DOWNLOAD").")</a>";
					break;
					default:
						// unknown
						$row["OBJECT"] = "<a href=\"{$row["MediaURL"]}\"><img class=\"photo\" src=\""._l("C_SITE.REL_URL")."{$row["Thumbnail"]}\" width=\"{$row["THUMBNAIL.WIDTH"]}\" height=\"{$row["THUMBNAIL.HEIGHT"]}\" alt=\"{$row["Title"]}\" title=\"{$row["Title"]}\" /></a><br />("._l("L_CLICK_TO_DOWNLOAD").")";
					break;
				}

				$row["AUTHOR"] = getUserById($row["AuthorID"]);

				$row["BLOCK_TITLE"] = $row["Title"];
				$row["BLOCK_ICON"] = mkIcon("gallery.png", 16);

				$tpl->set_arr($row);

				$mcBuff = $tpl->make();

				// loading comments
				if ($row["AllowComments"]) {
					$mcBuff .= LoadCommentsBlock (
						"gallery",
						$row["ID"],
						"index.php/gallery/item/".urlencode($row["Title"])."?id={$row["ID"]}&page=%p",
						$page,
						$row["Title"]
					);
				}
			} else {
				$mcBuff = accessDenied();
			}
		break;
		case "items":

			$id = _ext("id");
			$page = _ext("page");

			$tpl = new contentBlock();

			$tpl->insert("BLOCK_CONTENT", "gallery/view_gallery.tpl");

			$db->query("SELECT
			ID, Title, Description, Thumbnail, ThumbnailSize, auth_Access
			FROM ".db_table("gallery")." WHERE ID = '{$id}'",
			__FILE__, __LINE__);

			$row = $db->fetch_row();

			if ($db->num_rows() && gauth($row["auth_Access"])) {

				/* subgalleries */
				$allowed_galleries_sql = "(ID = '".implode("' OR ID ='", get_allowed_categories($row["ID"]))."')";

				$db->query ("SELECT
				ID, Title, Description, Thumbnail, ThumbnailSize, AuthorID, LastUpdated
				FROM ".db_table("gallery")." WHERE {$allowed_galleries_sql}",
				__FILE__, __LINE__);

				$subgalleries = $db->num_rows();
				while ($row2 = $db->fetch_row()) {
					gallery_row($row2);

					$tpl->set_arr($row2, "SUBGALLERY");
					$tpl->savebuff("SUBGALLERY");
				}

				/* gallery items */
				$pager = $db->pager (
					"SELECT ID FROM ".db_table("gallery_item")."
					WHERE GalleryLink = '{$row["ID"]}'",
					"index.php/gallery/items/".urlencode($row["Title"])."?id={$row["ID"]}&page=%p", $page, conf::getkey("gallery", "items_per_page")
				);

				$db->query("SELECT ID, Title, Description, Thumbnail, ThumbnailSize,
				LastUpdated, AuthorID, AllowComments
				FROM ".db_Table("gallery_item")."
				WHERE GalleryLink = '{$row["ID"]}' {$pager["sql"]}", __FILE__, __LINE__);

				$items = $db->num_rows();

				while ($row2 = $db->fetch_row()) {
					saneHTML($row2, "Description");
					gallery_row($row2, true);
					$row2["COMMENTSLINK"] = $row2["AllowComments"] ? mkCommentsLink("gallery", $row2["ID"], "index.php/gallery/view/{$row2["TITLE_ID"]}?id={$row2["ID"]}") : "";
					$tpl->set_arr($row2, "ITEM");
					$tpl->savebuff("ITEM");
				}

				$tpl->set_arr ($row);
				$tpl->set_arr (
					Array (
						"BLOCK_TITLE" => _l("L_GALLERY"),
						"BLOCK_ICON" => mkIcon("gallery.png", 16),
						"BLOCK_SUBTITLE" => $row["Title"],
						"ITEMS" => $items,
						"SUBGALLERIES" => $subgalleries,
						"PAGER" => $pager["html"]
					)
				);

				$mcBuff = $tpl->make();
			} else {
				$mcBuff = accessDenied();
			}
		break;
		default: {

			$tpl = new ContentBlock();
			$tpl->insert("BLOCK_CONTENT", "gallery/index.tpl");

			$allowed_galleries_sql = "(ID = '".implode("' OR ID ='", get_allowed_categories())."')";

			$pager = $db->pager (
				"SELECT ID FROM ".db_table("gallery")."
				WHERE {$allowed_galleries_sql} ORDER BY Title DESC",
				"index.php/gallery/%p", $page, conf::getKey("gallery", "items_per_page")
			);

			$db->query("SELECT
			ID, Title, Description, Thumbnail, ThumbnailSize, AuthorID, LastUpdated
			FROM ".db_table("gallery")." WHERE {$allowed_galleries_sql} ORDER BY
			Title DESC {$pager["sql"]}", __FILE__, __LINE__);

			$galleries = $db->num_rows();
			while ($row = $db->fetch_row()) {
				gallery_row($row);
				$tpl->set_arr($row, "GALLERY");
				$tpl->savebuff("GALLERY");
			}

			$tpl->set_arr (
				Array (
					"BLOCK_TITLE" => _l("L_GALLERY"),
					"BLOCK_SUBTITLE" => _l("L_GALLERIES"),
					"BLOCK_ICON" => mkIcon("gallery.png", 16),
					"PAGER" => $pager["html"],
					"GALLERIES" => $galleries
				)
			);

			$mcBuff = $tpl->make();

		}
	}

	// saving buffer
	$mc->save($mcBuff);

?>
